import React from 'react';
import { useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar'; 
import '../../styles/ProductList.css';

const CategoryList = () => {
  const navigate = useNavigate();

  // Updated categories array with names and specifications
  const categories = [
    { name: 'Shirts', image: 'https://www2.hm.com/en_in/productpage.1032522123.html', description: 'shirts' },
    { name: 'Suits', image: 'https://www2.hm.com/en_in/productpage.1032522123.html', description: 'suits' },
    { name: 'Tuxedos', image: 'https://www2.hm.com/en_in/productpage.1032522123.html', description: 'tuxedos' },
    { name: 'Jackets', image: 'https://image.coolblue.nl/422x390/products/1101120', description: 'jackets' },
  ];

  const handleClick = (category) => {
    navigate(`/products/${category}`);
  };

  return (
    <div className="flex h-screen">
      {/* Sidebar */}
      <Sidebar />

      {/* Main content */}
      <div className="flex-grow flex flex-col">
        <div className="bg-white p-4 flex items-center">
          <h1 className="ml-4 text-2xl font-medium text-gray-700">Categories</h1>
        </div>
        <div className="flex-grow p-8">
          <div className="grid grid-cols-2 gap-8">
            {categories.map((category, index) => (
              <div
                key={index}
                className="border border-gray-300 p-4 rounded-lg cursor-pointer hover:shadow-lg transition-shadow duration-300 ease-in-out flex flex-col items-center"
                onClick={() => handleClick(category.name.toLowerCase())} // Updated to handle lowercase category names
              >
                <img src={category.image} alt={category.name} className="w-48 h-48 object-cover" />
                <h2 className="text-xl font-bold text-center mt-2 capitalize">{category.name}</h2>
                <p className="ml-4 text-2xl font-medium text-gray-700">{category.description}</p>
                <p className="text-center text-sm text-gray-600 mt-1">Click to view products</p>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

export default CategoryList;
