import React, { useState } from 'react';
import { useParams, useNavigate, Link } from 'react-router-dom';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Sidebar from '../sidebar/Sidebar'; 
import '../../styles/Customize.css';



const Customize = () => {
  const { id } = useParams();
  const navigate = useNavigate();
  const [style, setStyle] = useState('');
  const [material, setMaterial] = useState('');

  const handleStyleChange = (event) => {
    setStyle(event.target.value);
  };

  const handleMaterialChange = (event) => {
    setMaterial(event.target.value);
  };

  const handleSave = () => {
    const customization = {
      productId: id,
      style,
      material,
    };

    fetch('/api/saveCustomization', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(customization),
    })
      .then(response => response.json())
      .then(data => {
        console.log('Success:', data);
        navigate('/');
      })
      .catch((error) => {
        console.error('Error:', error);
      });
  };

  return (
    <div className="flex h-screen ">
      {/* Sidebar */}
      <Sidebar />

      {/* Main content */}
      <div className="flex-grow flex flex-col">
        <div className="bg-white p-4 flex items-center">
          <Link to="/CategoryList" className="">
            <FontAwesomeIcon icon={faChevronLeft} />
          </Link>
          <h1 className="ml-4 text-2xl font-medium text-gray-700 ">Customize Product</h1>
        </div>
        <div className="flex-grow flex items-center justify-center p-8">
          <div className="bg-white p-6 rounded-lg shadow-lg w-full max-w-md">
            <div className="mb-4">
              <label className="block text-sm font-medium text-gray-700">
                Style:
                <select
                  value={style}
                  onChange={handleStyleChange}
                  className="mt-1 block w-full py-2 px-3 "
                >
                  <option value="">Select style</option>
                  <option value="collar">Collar</option>
                  <option value="cuff">Cuff</option>
                  <option value="placket">Placket</option>
                </select>
              </label>
            </div>
            <div className="mb-4">
              <label className="block text-sm font-medium text-gray-700">
                Material:
                <select
                  value={material}
                  onChange={handleMaterialChange}
                  className="mt-1 block w-full "
                >
                  <option value="">Select material</option>
                  <option value="cotton">Cotton</option>
                  <option value="polyester">Polyester</option>
                  <option value="linen">Linen</option>
                </select>
              </label>
            </div>
            <button
              onClick={handleSave}
              className="w-full py-2 px-4"
            >
              Save Style and Material
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Customize;
