import React from 'react';
import { Layout } from 'antd';
import { Link } from 'react-router-dom';
import BrookslogoIcon from '../../assets/thob-data/BrookslogoIcon.svg';
import HomeIcon from '../../assets/thob-data/HomeIcon.svg';
import AddCustomerIcon from '../../assets/thob-data/AddCustomerIcon.svg';
import OrdersIcon from '../../assets/thob-data/OrdersIcon.svg';
import CategoriesIcon from '../../assets/thob-data/CategoriesIcon.svg';
import ProfileIcon from '../../assets/thob-data/ProfileIcon.svg';
import LogoutIcon from '../../assets/thob-data/LogoutIcon.svg';
import '../../styles/EmployeeSidebar.css'; 

const { Sider } = Layout;

const classNames = {
  sider: 'desktop-sidebar',
  container: 'flex flex-col items-center mt-4 h-full justify-between',
  logoContainer: 'flex items-center justify-center h-16 w-16 mb-5 bg-white',
  iconContainer: 'flex flex-col items-center flex-grow',
  iconLink: 'my-6',
  icon: 'hover:opacity-75 sidebar-icon',
  logoutContainer: 'flex items-center justify-center mb-4',
};

const EmployeeSidebar = () => {
  return (
    <Sider
      className={classNames.sider}
      breakpoint="lg"
      collapsedWidth="0"
      width={70}
      style={{ height: '100vh', display: 'flex', flexDirection: 'column', justifyContent: 'space-between' }}
    >
      <div className={classNames.container}>
        <div className={classNames.logoContainer}>
          <Link to="">
            <img src={BrookslogoIcon} alt="Brooks Bingham Logo" className={classNames.icon} />
          </Link>
        </div>
        <div className={classNames.iconContainer}>
          <Link to="/employee/home" className={classNames.iconLink}>
            <img src={HomeIcon} alt="Home" className={classNames.icon} />
          </Link>
          <Link to="/CategoryList" className={classNames.iconLink}>
            <img src={CategoriesIcon} alt="Categories" className={classNames.icon} />
          </Link>
          <Link to="/customers" className={classNames.iconLink}>
            <img src={AddCustomerIcon} alt="Add Customer" className={classNames.icon} />
          </Link>
          <Link to="/employee/orders" className={classNames.iconLink}>
            <img src={OrdersIcon} alt="Orders" className={classNames.icon} />
          </Link>
          <Link to="/employee/profile" className={classNames.iconLink}>
            <img src={ProfileIcon} alt="Profile" className={classNames.icon} />
          </Link>
        </div>
      </div>
      <div className={classNames.logoutContainer}>
        <Link to="/employee/logout">
          <img src={LogoutIcon} alt="Logout" className={classNames.icon} />
        </Link>
      </div>
    </Sider>
  );
};

export default EmployeeSidebar;
