import axiosInstance from "../api/axiosConfig"; // Import the global axios instance

// Get all customers
export const getAllCustomers = async () => {
  try {
    const response = await axiosInstance.get("/customers");
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

export const getCustomers = async () => {
    // Implementation
  };

export const addCustomer = async (customer) => {
    // Implementation
  };

// Create a new customer
export const createCustomer = async (customerPayload) => {
  try {
    const response = await axiosInstance.post("/customers", customerPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get a customer by ID
export const getCustomerById = async (id) => {
  try {
    const response = await axiosInstance.get(`/customers/${id}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Update a customer's details
export const updateCustomer = async (id, customerPayload) => {
  try {
    const response = await axiosInstance.patch(
      `/customers/${id}`,
      customerPayload
    );
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Delete a customer
export const deleteCustomer = async (id) => {
  try {
    await axiosInstance.delete(`/customers/${id}`);
    return; // No content to return on successful delete
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Example function to use the service
export const exampleUsage = async () => {
  try {
    // Example: Get all customers
    const customers = await getAllCustomers();
    console.log("Customers:", customers);

    // Example: Create a new customer
    const newCustomer = { name: "Alice Johnson", email: "alice@example.com" };
    const createdCustomer = await createCustomer(newCustomer);
    console.log("Created Customer:", createdCustomer);

    // Example: Get a customer by ID
    const customerId = "456";
    const customer = await getCustomerById(customerId);
    console.log("Customer by ID:", customer);

    // Example: Update a customer
    const updatedCustomerPayload = { email: "alice.johnson@example.com" };
    const updatedCustomer = await updateCustomer(
      customerId,
      updatedCustomerPayload
    );
    console.log("Updated Customer:", updatedCustomer);

    // Example: Delete a customer
    await deleteCustomer(customerId);
    console.log("Customer deleted successfully");
  } catch (error) {
    console.error("Error occurred while using customers service:", error);
  }
};
