import axiosInstance from '../api/axiosConfig'; // Import the global axios instance

// Get all orders with their metadata
export const getAllOrders = async () => {
  try {
    const response = await axiosInstance.get('/orders');
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Create a new order
export const createOrder = async (orderPayload) => {
  try {
    const response = await axiosInstance.post('/orders', orderPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get an order by ID
export const getOrderById = async (id) => {
  try {
    const response = await axiosInstance.get(`/orders/${id}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Update an order's details
export const updateOrder = async (id, orderPayload) => {
  try {
    const response = await axiosInstance.patch(`/orders/${id}`, orderPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Delete an order
export const deleteOrder = async (id) => {
  try {
    await axiosInstance.delete(`/orders/${id}`);
    return; // No content to return on successful delete
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Example function to use the service
export const exampleUsage = async () => {
  try {
    // Example: Get all orders
    const orders = await getAllOrders();
    console.log('Orders:', orders);

    // Example: Create a new order
    const newOrder = { productId: '123', quantity: 2, status: 'pending' };
    const createdOrder = await createOrder(newOrder);
    console.log('Created Order:', createdOrder);

    // Example: Get an order by ID
    const orderId = '456';
    const order = await getOrderById(orderId);
    console.log('Order by ID:', order);

    // Example: Update an order
    const updatedOrderPayload = { status: 'shipped' };
    const updatedOrder = await updateOrder(orderId, updatedOrderPayload);
    console.log('Updated Order:', updatedOrder);

    // Example: Delete an order
    await deleteOrder(orderId);
    console.log('Order deleted successfully');
  } catch (error) {
    console.error('Error occurred while using orders service:', error);
  }
};
