import axiosInstance from "../api/axiosConfig"; 

// Get all users with their metadata
export const getAllUsers = async () => {
  try {
    const response = await axiosInstance.get("/users");
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Create a new user
export const createUser = async (userPayload) => {
  try {
    const response = await axiosInstance.post("/users", userPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Get a user by ID
export const getUserById = async (id) => {
  try {
    const response = await axiosInstance.get(`/users/${id}`);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Update a user's details
export const updateUser = async (id, userPayload) => {
  try {
    const response = await axiosInstance.patch(`/users/${id}`, userPayload);
    return response.data;
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Delete a user
export const deleteUser = async (id) => {
  try {
    await axiosInstance.delete(`/users/${id}`);
    return; // No content to return on successful delete
  } catch (error) {
    throw error; // The error is handled globally by the axiosInstance
  }
};

// Example function to use the service
export const exampleUsage = async () => {
  try {
    // Example: Get all users
    const users = await getAllUsers();
    console.log("Users:", users);

    // Example: Create a new user
    const newUser = { name: "John Doe", email: "john@example.com" };
    const createdUser = await createUser(newUser);
    console.log("Created User:", createdUser);

    // Example: Get a user by ID
    const userId = "123";
    const user = await getUserById(userId);
    console.log("User by ID:", user);

    // Example: Update a user
    const updatedUserPayload = { name: "John Smith" };
    const updatedUser = await updateUser(userId, updatedUserPayload);
    console.log("Updated User:", updatedUser);

    // Example: Delete a user
    await deleteUser(userId);
    console.log("User deleted successfully");
  } catch (error) {
    console.error("Error occurred while using users service:", error);
  }
};
